@@ -1,7 +1,7 @@
 package Benchmark::Command;
 
-our $DATE = '2015-06-13'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $DATE = '2015-06-14'; # DATE
+our $VERSION = '0.08'; # VERSION
 
 use 5.010001;
 use strict;
@@ -14,6 +14,8 @@ use File::Which;
 sub run {
     my ($count, $cmds, $opts) = @_;
 
+    $count //= $ENV{BENCHMARK_COMMAND_COUNT} // 0;
+
     $opts //= {};
     $opts->{quiet} //= $ENV{BENCHMARK_COMMAND_QUIET} // $ENV{QUIET} // 0;
     $opts->{ignore_exit_code} //= $ENV{BENCHMARK_COMMAND_IGNORE_EXIT_CODE} // 0;
@@ -123,7 +125,7 @@ Benchmark::Command - Benchmark commands
 
 =head1 VERSION
 
-This document describes version 0.07 of Benchmark::Command (from Perl distribution Benchmark-Command), released on 2015-06-13.
+This document describes version 0.08 of Benchmark::Command (from Perl distribution Benchmark-Command), released on 2015-06-14.
 
 =head1 SYNOPSIS
 
@@ -228,6 +230,10 @@ This overrides global C<skip_not_found> option.
 
 =head1 ENVIRONMENT
 
+=head2 BENCHMARK_COMMAND_COUNT => num
+
+Set default for C<run()>'s C<$count> argument.
+
 =head2 BENCHMARK_COMMAND_IGNORE_EXIT_CODE => bool
 
 Set default for C<run()>'s C<ignore_exit_code> option.
